Module ir

Module ir 

Structs

ApiSurface
Complete API surface extracted from a Rust crate’s public interface.
EnumDef
A public enum.
EnumVariant
An enum variant.
ErrorDef
An error type (enum used in Result<T, E>).
ErrorVariant
An error variant.
FieldDef
A field on a public struct.
FunctionDef
A free function exposed to bindings.
MethodDef
A method on a public struct.
ParamDef
A function/method parameter.
TypeDef
A public struct exposed to bindings.

Enums

CoreWrapper
Indicates the core Rust type wraps the resolved type in a smart pointer or cow. Used by codegen to generate correct From/Into conversions.
DefaultValue
Typed default value for a field, enabling backends to emit language-native defaults.
PrimitiveType
Rust primitive types.
ReceiverKind
How self is received.
TypeRef
Reference to a type, with enough info for codegen.