python_ident

Function python_ident 

pub fn python_ident(name: &str) -> String
Like python_safe_name but always returns a String, using the original when no escaping is needed. Convenience wrapper for call sites that always need a String.